smartcard.pcsc.PCSCReaderGroups.PCSCReaderGroups

# ``smartcard`.`pcsc`.`PCSCReaderGroups`.`PCSCReaderGroups``

class documentation

`class PCSCReaderGroups(readergroups):`

View In Hierarchy

PCSC readers groups.

Method | `__init__` | Create a single instance of pcscinnerreadergroups on first call
Instance Variable | `innerclazz` | Undocumented

Inherited from `readergroups`:

Method | `__getattr__` | Undocumented
Class Variable | `instance` | Undocumented

def __init__(self, initlist=None):
overrides `smartcard.reader.ReaderGroups.readergroups.__init__`

Create a single instance of pcscinnerreadergroups on first call

innerclazz =

Undocumented